### Name: ArcGIS Geoprocessing Tools
### Title: Wrappers for selected ArcGIS functions
### Aliases: rpygeo.EucDistance.sa rpygeo.Aspect.sa rpygeo.Slope.sa
###   rpygeo.Hillshade.sa rpygeo.Curvature.sa rpygeo.Delete.management
### Keywords: interface database

### ** Examples

# Allow ArcGIS to overwrite existing datasets:
## Not run: 
##D rpygeo.env$overwriteoutput = 1
##D # Calculate the slope of a DEM raster dataset
##D # in the current ArcGIS workspace:
##D rpygeo.geoprocessor("Slope_sa",c("dem","slope"))
##D # Same:
##D rpygeo.geoprocessor("Slope_sa('dem','slope')")
##D # Same, using the more convenient wrapper:
##D rpygeo.Slope.sa("dem","slope")
## End(Not run)

# Three at a time or separately:
## Not run: 
##D date()
##D rpygeo.geoprocessor("Slope_sa('dem','slope')",
##D   "Aspect_sa('dem','aspect')", "Hillshade_sa('dem','hshd')")
##D date() # ~20 sec on my computer
##D rpygeo.Slope.sa("dem","slope")
##D rpygeo.Aspect.sa("dem","aspect")
##D rpygeo.Hillshade.sa("dem","hshd")
##D date() # ~50 sec
##D rpygeo.Delete.management("slope")
##D rpygeo.Delete.management("aspect")
##D rpygeo.Delete.management("hshd")
## End(Not run)

# Calculate the Euclidian distance from railway lines
# up to a max. distance of 1000 map units:
## Not run: 
##D rpygeo.geoprocessor("EucDistance_sa",
##D     args=list("rail.shp","raildist",1000))
##D # Same:
##D rpygeo.EucDistance.sa("rail.shp","raildist",maxdist=1000)
## End(Not run)

# Use MapAlgebra to calculate a distance-decay function:
## Not run: 
##D rpygeo.geoprocessor("SingleOutputMapAlgebra_sa",
##D     args=c("exp( raildist / -100 )","distdecay"))
## End(Not run)

# Or why not in just one step if you like MapAlgebra:
## Not run: 
##D rpygeo.geoprocessor( "SingleOutputMapAlgebra_sa",
##D     args=c("exp( EucDistance( rail.shp, \#, \#, 1000 ) / -100 )","distdecay") )
## End(Not run)



